@@ -1,4 +1,4 @@
-/* $Id: terminal-dbus.c 136 2005-03-14 17:42:30Z bmeurer $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004-2005 os-cillation e.K.
  *
@@ -36,8 +36,6 @@
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
-#include <libxfce4util/libxfce4util.h>
-
 #include <terminal/terminal-config.h>
 #include <terminal/terminal-dbus.h>
 
@@ -60,7 +58,7 @@ handle_message (DBusConnection *connection,
   DBusMessage *reply;
   DBusError    derror;
   GError      *error = NULL;
-  uid_t        user_id;
+  dbus_int64_t user_id;
   gchar      **argv;
   gint         argc;
 
@@ -168,7 +166,7 @@ gboolean
 terminal_dbus_register_service (TerminalApp *app,
                                 GError     **error)
 {
-  static const struct DBusObjectPathVTable vtable = { NULL, handle_message, NULL, };
+  static const struct DBusObjectPathVTable vtable = { NULL, handle_message, NULL, NULL, NULL, NULL };
 
   DBusConnection *connection;
   DBusError       derror;
@@ -202,7 +200,7 @@ terminal_dbus_register_service (TerminalApp *app,
     }
 
   /* register the application object */
-  if (dbus_connection_register_object_path (connection, TERMINAL_DBUS_PATH, &vtable, app) < 0)
+  if (!dbus_connection_register_object_path (connection, TERMINAL_DBUS_PATH, &vtable, app))
     {
       g_set_error (error, DBUS_GERROR, DBUS_GERROR_FAILED,
                    _("Unable to register object %s"),
@@ -210,7 +208,7 @@ terminal_dbus_register_service (TerminalApp *app,
       return FALSE;
     }
 
-  g_object_set_data_full (G_OBJECT (app), "terminal-dbus-connection",
+  g_object_set_data_full (G_OBJECT (app), I_("terminal-dbus-connection"),
                           connection, (GDestroyNotify) dbus_connection_unref);
 
   return TRUE;
