@@ -1,6 +1,6 @@
-/* $Id: terminal-shortcut-editor.c 123 2005-01-30 23:49:36Z bmeurer $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2004-2005 os-cillation e.K.
+ * Copyright (c) 2004-2007 os-cillation e.K.
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
  *
@@ -29,6 +29,13 @@
 
 #include <terminal/terminal-preferences.h>
 #include <terminal/terminal-shortcut-editor.h>
+#include <terminal/terminal-stock.h>
+
+#if defined(GDK_WINDOWING_WIN32)
+#include <gdk/gdkwin32.h>
+#elif defined(GDK_WINDOWING_X11)
+#include <gdk/gdkx.h>
+#endif
 
 
 
@@ -77,15 +84,14 @@ struct _TerminalShortcutEditor
 
 
 
-static GObjectClass *parent_class;
-
-static ToplevelMenu toplevel_menus[] =
+static const ToplevelMenu toplevel_menus[] =
 {
   {
     N_ ("File"),
     {
       "accel-new-tab",
       "accel-new-window",
+      "accel-detach-tab",
       "accel-close-tab",
       "accel-close-window",
       NULL,
@@ -96,6 +102,7 @@ static ToplevelMenu toplevel_menus[] =
     {
       "accel-copy",
       "accel-paste",
+      "accel-paste-selection",
       "accel-preferences",
       NULL,
     },
@@ -156,8 +163,6 @@ terminal_shortcut_editor_class_init (TerminalShortcutEditorClass *klass)
 {
   GObjectClass *gobject_class;
 
-  parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = terminal_shortcut_editor_finalize;
 }
@@ -167,16 +172,16 @@ terminal_shortcut_editor_class_init (TerminalShortcutEditorClass *klass)
 static void
 terminal_shortcut_editor_init (TerminalShortcutEditor *editor)
 {
-  GtkTreeViewColumn *column;
-  GtkCellRenderer   *renderer;
-  ToplevelMenu      *menu;
-  GtkTreeStore      *store;
-  GtkTreeIter        parent;
-  GtkTreeIter        child;
-  GParamSpec        *pspec;
-  gchar             *signal;
-  gchar             *accel;
-  gint               n;
+  const ToplevelMenu *menu;
+  GtkTreeViewColumn  *column;
+  GtkCellRenderer    *renderer;
+  GtkTreeStore       *store;
+  GtkTreeIter         parent;
+  GtkTreeIter         child;
+  GParamSpec         *pspec;
+  gchar              *signal;
+  gchar              *accel;
+  gint                n;
 
   editor->preferences = terminal_preferences_get ();
 
@@ -249,7 +254,7 @@ terminal_shortcut_editor_finalize (GObject *object)
                                         editor);
   g_object_unref (G_OBJECT (editor->preferences));
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  (*G_OBJECT_CLASS (terminal_shortcut_editor_parent_class)->finalize) (object);
 }
 
 
@@ -257,6 +262,24 @@ terminal_shortcut_editor_finalize (GObject *object)
 static gboolean
 is_modifier (guint keycode)
 {
+#if defined(GDK_WINDOWING_WIN32)
+  switch (keycode)
+    {
+    case VK_ALT:
+    case VK_LALT:
+    case VK_RALT:
+    case VK_CONTROL:
+    case VK_LCONTROL:
+    case VK_RCONTROL:
+    case VK_SHIFT:
+    case VK_LSHIFT:
+    case VK_RSHIFT:
+      return TRUE;
+
+    default:
+      return FALSE;
+    }
+#elif (defined(GDK_WINDOWING_X11) && defined(HAVE_LIBX11))
   XModifierKeymap *keymap;
   gboolean         result = FALSE;
   gint             n;
@@ -272,6 +295,9 @@ is_modifier (guint keycode)
   XFreeModifiermap (keymap);
 
   return result;
+#else
+  return FALSE;
+#endif
 }
 
 
@@ -318,7 +344,7 @@ terminal_shortcut_editor_activate (TerminalShortcutEditor *editor,
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  image = gtk_image_new_from_stock ("terminal-compose", GTK_ICON_SIZE_DIALOG);
+  image = gtk_image_new_from_stock (TERMINAL_STOCK_COMPOSE, GTK_ICON_SIZE_DIALOG);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
   gtk_widget_show (image);
 
@@ -338,25 +364,25 @@ terminal_shortcut_editor_activate (TerminalShortcutEditor *editor,
 
   gtk_widget_show_now (dialog);
 
-  if (gdk_keyboard_grab (dialog->window, FALSE,
-                         GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
+  if (gdk_keyboard_grab (dialog->window, FALSE, GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
     {
       message = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog),
                                                     GTK_DIALOG_DESTROY_WITH_PARENT
                                                     | GTK_DIALOG_MODAL,
                                                     GTK_MESSAGE_ERROR,
                                                     GTK_BUTTONS_CLOSE,
-                                                    "<big>%s</big>\n\n%s",
-                                                    _("Failed to acquire keyboard"),
-                                                    _("Another application has already acquired "
-                                                      "control over your keyboard."));
+                                                    "%s.",
+                                                    _("Failed to acquire keyboard"));
+      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
+                                                _("Another application has already acquired "
+                                                  "control over your keyboard."));
       gtk_dialog_run (GTK_DIALOG (message));
       gtk_widget_destroy (message);
       goto done;
     }
 
   gtk_tree_model_get (model, &iter, COLUMN_PROPERTY, &property, -1);
-  g_object_set_data_full (G_OBJECT (dialog), "property-name", property, g_free);
+  g_object_set_data_full (G_OBJECT (dialog), I_("property-name"), property, g_free);
 
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
                     G_CALLBACK (terminal_shortcut_editor_compose), editor);
