@@ -1,4 +1,4 @@
-/* $Id: terminal-tab-header.h 19290 2006-01-03 20:57:08Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004 os-cillation e.K.
  *
@@ -36,6 +36,21 @@ G_BEGIN_DECLS;
 typedef struct _TerminalTabHeaderClass TerminalTabHeaderClass;
 typedef struct _TerminalTabHeader      TerminalTabHeader;
 
+struct _TerminalTabHeader
+{
+  GtkHBox              __parent__;
+
+  TerminalPreferences *preferences;
+
+  GtkWidget           *ebox;
+  GtkWidget           *label;
+
+  /* the popup menu */
+  GtkWidget           *menu;
+
+  ExoBinding          *tab_pos_binding;
+};
+
 GType      terminal_tab_header_get_type (void) G_GNUC_CONST;
 
 GtkWidget *terminal_tab_header_new      (void);
